==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/FilterDialogRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterDialogRenderCompletedEventArgsDescription } from "./FilterDialogRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
export let FilterDialogRenderCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterDialogRenderCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FilterDialogRenderCompletedEventArgsDescriptionMetadata.a == null) {
                FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterDialogRenderCompletedEventArgsDescriptionMetadata.c(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.j(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.b(a);
            a.aa("FilterDialogRenderCompletedEventArgs", () => new FilterDialogRenderCompletedEventArgsDescription());
            a.z("FilterDialogRenderCompletedEventArgs", FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
        }
    }
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FilterDialogRenderCompletedEventArgsDescriptionMetadata, 'FilterDialogRenderCompletedEventArgsDescriptionMetadata');
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = null;
    return FilterDialogRenderCompletedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FilterDialogRenderCompletedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterDialogRenderCompletedEventArgsDescription } from "./FilterDialogRenderCompletedEventArgsDescription";
/**
 * @hidden
 */
export let FilterDialogRenderCompletedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class FilterDialogRenderCompletedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (FilterDialogRenderCompletedEventArgsDescriptionMetadata.a == null) {
                FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FilterDialogRenderCompletedEventArgsDescriptionMetadata.c(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
            }
            if (a.k(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            FilterDialogRenderCompletedEventArgsDescriptionMetadata.b(a);
            a.ac("FilterDialogRenderCompletedEventArgs", () => new FilterDialogRenderCompletedEventArgsDescription());
            a.ab("FilterDialogRenderCompletedEventArgs", FilterDialogRenderCompletedEventArgsDescriptionMetadata.a);
        }
    }
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(FilterDialogRenderCompletedEventArgsDescriptionMetadata, 'FilterDialogRenderCompletedEventArgsDescriptionMetadata');
    FilterDialogRenderCompletedEventArgsDescriptionMetadata.a = null;
    return FilterDialogRenderCompletedEventArgsDescriptionMetadata;
})();
